@@ -1,4 +1,4 @@
-# $Id: Request.pm 37839 2012-09-17 09:33:01Z wsl $
+# $Id: Request.pm 39280 2013-04-22 14:45:43Z wsl $
 # $URL: https://svn.uvt.nl/its-id/trunk/sources/aselect-perl/lib/Aselect/WS/ValidateCAS/Request.pm $
 
 use strict;
@@ -7,12 +7,15 @@ use utf8;
 
 package Aselect::WS::ValidateCAS::Request;
 
+use Aselect::URL qw(normalize_url);
+
 use Aselect::Request -self;
 
 param service => sub {
 	my $self = shift;
 	die $self->error("Required request parameter 'service' not supplied") unless defined;
-	s/^http:/https:/ if $self->cfg->https_everywhere;
+	$_ = normalize_url($_);
+	$_ = $self->apply_https_everywhere($_);
 };
 param ticket => sub { die shift->error("Required request parameter 'ticket' not supplied") unless defined };
 param pgtUrl => sub { 'FIXME' };
